# wireui

A tool for creating and managing wireguard configs  
Version 0.1.0a3  
&copy; 2020 Tim Schlottmann  

## Installation

Please run
```
python3 -m pip install wireui-TheTimmoth
```

## Usage

Please run
```
python3 -m wireui
```

### Hints

* Please note: the documentation for the API will not be created until release 0.1.0rc1
